==> PySDM-examples-1.20.tar.gz: PySDM-examples-1.20/PySDM_examples/UIUC_2021/make_particulator.py <==
import numpy as np
from PySDM.builder import Builder
from PySDM.backends import CPU
from PySDM.physics import Formulae
from PySDM.dynamics import Freezing
from PySDM.environments import Box
from PySDM.initialisation.spectral_sampling import ConstantMultiplicity
from PySDM.initialisation.spectro_glacial import SpectroGlacialSampling
from PySDM import products as PySDM_products


A_VALUE_LARGER_THAN_ONE = 44


def make_particulator(*, n_sd, dt, initial_temperature, singular, seed,
                      shima_T_fz, ABIFM_spec, droplet_volume, total_particle_number, volume):
    attributes = {
        'volume': np.ones(n_sd) * droplet_volume
    }

    formulae_ctor_args = {'seed': seed}
    if singular:
        formulae_ctor_args['freezing_temperature_spectrum'] = shima_T_fz
    else:
        formulae_ctor_args['heterogeneous_ice_nucleation_rate'] = 'ABIFM'
    formulae = Formulae(**formulae_ctor_args)

    if singular:
        sampling = SpectroGlacialSampling(
            freezing_temperature_spectrum=formulae.freezing_temperature_spectrum,
            insoluble_surface_spectrum=ABIFM_spec,
            seed=formulae.seed
        )
        attributes['freezing temperature'], _, attributes['n'] = sampling.sample(n_sd)
    else:
        sampling = ConstantMultiplicity(
            spectrum=ABIFM_spec,
            # seed=formulae.seed
        )
        attributes['immersed surface area'], attributes['n'] = sampling.sample(n_sd)
    attributes['n'] *= total_particle_number

    builder = Builder(n_sd, CPU(formulae))

    env = Box(dt, volume)
    builder.set_environment(env)
    env['T'] = initial_temperature
    env['RH'] = A_VALUE_LARGER_THAN_ONE

    builder.add_dynamic(Freezing(singular=singular))

    return builder.build(
        attributes=attributes,
        products=[
            PySDM_products.Time(),
            PySDM_products.Temperature(),
            PySDM_products.IceWaterContent(specific=False)
        ]
    )

==> PySDM-examples-1.21.tar.gz: PySDM-examples-1.21/PySDM_examples/UIUC_2021/make_particulator.py <==
import numpy as np
from PySDM.builder import Builder
from PySDM.backends import CPU
from PySDM.physics import Formulae
from PySDM.dynamics import Freezing
from PySDM.environments import Box
from PySDM.initialisation.spectral_sampling import ConstantMultiplicity
from PySDM.initialisation.spectro_glacial import SpectroGlacialSampling
from PySDM import products as PySDM_products


A_VALUE_LARGER_THAN_ONE = 44


def make_particulator(*, n_sd, dt, initial_temperature, singular, seed,
                      shima_T_fz, ABIFM_spec, droplet_volume, total_particle_number, volume):
    attributes = {
        'volume': np.ones(n_sd) * droplet_volume
    }

    formulae_ctor_args = {'seed': seed}
    if singular:
        formulae_ctor_args['freezing_temperature_spectrum'] = shima_T_fz
    else:
        formulae_ctor_args['heterogeneous_ice_nucleation_rate'] = 'ABIFM'
    formulae = Formulae(**formulae_ctor_args)

    if singular:
        sampling = SpectroGlacialSampling(
            freezing_temperature_spectrum=formulae.freezing_temperature_spectrum,
            insoluble_surface_spectrum=ABIFM_spec,
            seed=formulae.seed
        )
        attributes['freezing temperature'], _, attributes['n'] = sampling.sample(n_sd)
    else:
        sampling = ConstantMultiplicity(
            spectrum=ABIFM_spec,
            # seed=formulae.seed
        )
        attributes['immersed surface area'], attributes['n'] = sampling.sample(n_sd)
    attributes['n'] *= total_particle_number

    builder = Builder(n_sd, CPU(formulae))

    env = Box(dt, volume)
    builder.set_environment(env)
    env['T'] = initial_temperature
    env['RH'] = A_VALUE_LARGER_THAN_ONE

    builder.add_dynamic(Freezing(singular=singular))

    return builder.build(
        attributes=attributes,
        products=[
            PySDM_products.Time(name='t'),
            PySDM_products.AmbientTemperature(name='T_env'),
            PySDM_products.SpecificIceWaterContent(name='qi')
        ]
    )
